%values from data (weighted by working age population)
n=2.99;
h=5;
c=1258.816; %hh consumption per worker
y0=1508.905; %output per worker
y1=2959.06;
N0=2.02;
N1=3.52;
mincer=0.11;
taug=0.045;

rho=0.33;
tau1=0.003;
hbar=1;
gA=1.56;

tauh=tau1+(taug/(n*h));

u0=[0.02, 2.7, 0.11];
u = fsolve(@(u) calibration(u, tauh, c, n, h, y0, y1, N0, N1, rho, gA),u0); 

tau0=u(1);
gH=u(2);
alpha=u(3);

z_lower=(gH-1)/h;
z_upper=gH/h;

z_vec=linspace(z_lower+0.001, z_upper-0.001, 9);
theta_vec=zeros(1, 9);
H0_vec=zeros(1, 9);

for i=1:9
    z=z_vec(1,i);
    x0=[0.02, 2.7];
    x = fsolve(@(x) calibration2(x, tauh, c, n, h, y0, gH, z, hbar),x0); 

    theta_vec(1,i)=x(1);
    H0_vec(1,i)=x(2);
end;

z_ideal=mincer*gH/(1-rho);
if (z_ideal<=z_upper) && (z_ideal>=z_lower)
    z=z_ideal;
    theta=gH*(tauh*n*y0/(z*c));
    H0=hbar*((1/(gH-(z*h)))-1);
elseif (z_ideal>=z_upper)
    z=z_upper;
    theta=theta_vec(1,9);
    H0=H0_vec(1,9);
else 
    z=z_lower;
    theta=theta_vec(1,1);
    H0=H0_vec(1,1);
end

%calibration of phi for norms model
psi=0.1;
nstar=1;
nprev=3.5;
phi=(n-nstar)/(nprev-nstar);
Hbar=hbar;


L=1; %land stock
A=1; %production technology
N0=2.21; %initial working age population

n_p=10;

phi_vec_policy=zeros(1,n_p);
phi_vec_policy(1,1)=phi;
phi_vec_policy(1,2)=0.6;
for i=3:n_p
    phi_vec_policy(1,i)=0.37;
end

%log disutility
%1. only norms - with policy change
u0=[3, 0.5];
u = fsolve(@(u) myfun_norm_log290416(u,tau0, tauh, theta, alpha, psi, nstar, nprev, phi, z, Hbar, H0),u0); 
nnl0 = u(1);
hdnl0 = u(2);

Ydnl0=A*(((Hbar+H0)*N0)^(1-rho))*((L)^(rho));
Pdnl0=N0+N0*nnl0;
ydnl0=Ydnl0/Pdnl0;
Xdnl0=L/N0;

hdnl = zeros(1,n_p);
Hdnl = zeros(1,n_p);
nnl_vec = zeros(1,n_p);
Ndnl = zeros(1,n_p);
Pdnl = zeros(1,n_p);
Ydnl = zeros(1,n_p);
ydnl = zeros(1,n_p);
Xdnl = zeros(1,n_p);
ygrownl=zeros(1,n_p-1);
pgrownl=zeros(1,n_p-1);

hdnl(1,1)=hdnl0;
Hdnl(1,1)=H0;
nnl_vec(1,1)=nnl0;
Ndnl(1,1)=N0;
Ydnl(1,1)=Ydnl0;
ydnl(1,1)=ydnl0;
Pdnl(1,1)=Pdnl0;
Xdnl(1,1)=Xdnl0;


for i=2:n_p
   phi=phi_vec_policy(1,i);
   Hdnl(1,i)=z*(Hbar+Hdnl(1,i-1))*(hdnl(1,i-1));
   H_use=Hdnl(1,i);
   Ndnl(1,i)=Ndnl(1,i-1)*nnl_vec(1,i-1);
   nprev_use=nnl_vec(1,i-1);
   
   u0=[nnl_vec(1,i-1), hdnl(1,i-1)];
   u = fsolve(@(u) myfun1_norm_log290416(u,tau0, tauh, theta, alpha, psi, nstar, nprev_use, phi, z, Hbar, H_use),u0);
   nnl_vec(1,i) = u(1);
   hdnl(1,i) = u(2);
  
   Ydnl(1,i)=A*(((Hbar+Hdnl(1,i))*Ndnl(1,i))^(1-rho))*((L)^(rho));
   Pdnl(1,i)=nnl_vec(1,i)*Ndnl(1,i)+Ndnl(1,i);
   ydnl(1,i)=Ydnl(1,i)/Pdnl(1,i);
   Xdnl(1,i)=L/Ndnl(1,i);
   
   ygrownl(1,i-1)=(ydnl(1,i)-ydnl(1,i-1))/ydnl(1,i-1);
   pgrownl(1,i-1)=(Pdnl(1,i)-Pdnl(1,i-1))/Pdnl(1,i-1);
end    

lnydnl=log(ydnl);
lnPdnl=log(Pdnl);
TFR_norml=2*nnl_vec;

%3. Norms only with no policy
phi=(n-nstar)/(nprev-nstar);
psi=0.1;

u0=[3, 0.5];
u = fsolve(@(u) myfun_norm_log290416(u,tau0, tauh, theta, alpha, psi, nstar, nprev, phi, z, Hbar, H0),u0); 
nnpl0 = u(1);
hdnpl0 = u(2);

Ydnpl0=A*(((Hbar+H0)*N0)^(1-rho))*((L)^(rho));
Pdnpl0=N0+N0*nnpl0;
ydnpl0=Ydnpl0/Pdnpl0;
Xdnpl0=L/N0;

hdnpl = zeros(1,n_p);
Hdnpl = zeros(1,n_p);
nnpl_vec = zeros(1,n_p);
Ndnpl = zeros(1,n_p);
Pdnpl = zeros(1,n_p);
Ydnpl = zeros(1,n_p);
ydnpl = zeros(1,n_p);
Xdnpl= zeros(1,n_p);
ygrownpl=zeros(1,n_p-1);
pgrownpl=zeros(1,n_p-1);

hdnpl(1,1)=hdnpl0;
Hdnpl(1,1)=H0;
nnpl_vec(1,1)=nnpl0;
Ndnpl(1,1)=N0;
Ydnpl(1,1)=Ydnpl0;
ydnpl(1,1)=ydnpl0;
Pdnpl(1,1)=Pdnpl0;
Xdnpl(1,1)=Xdnpl0;


for i=2:n_p
   Hdnpl(1,i)=z*(Hbar+Hdnpl(1,i-1))*(hdnpl(1,i-1));
   H_use=Hdnpl(1,i);
   Ndnpl(1,i)=Ndnpl(1,i-1)*nnpl_vec(1,i-1);
   nprev_use=nnpl_vec(1,i-1);
   
   u0=[nnpl_vec(1,i-1), hdnpl(1,i-1)];
   u = fsolve(@(u) myfun1_norm_log290416(u,tau0, tauh, theta, alpha, psi, nstar, nprev_use, phi, z, Hbar, H_use),u0);
   nnpl_vec(1,i) = u(1);
   hdnpl(1,i) = u(2);
  
   Ydnpl(1,i)=A*(((Hbar+Hdnpl(1,i))*Ndnpl(1,i))^(1-rho))*((L)^(rho));
   Pdnpl(1,i)=nnpl_vec(1,i)*Ndnpl(1,i)+Ndnpl(1,i);
   ydnpl(1,i)=Ydnpl(1,i)/Pdnpl(1,i);
   Xdnpl(1,i)=L/Ndnpl(1,i);
   
   ygrownpl(1,i-1)=(ydnpl(1,i)-ydnpl(1,i-1))/ydnpl(1,i-1);
   pgrownpl(1,i-1)=(Pdnpl(1,i)-Pdnpl(1,i-1))/Pdnpl(1,i-1);
end    

lnydnpl=log(ydnpl);
lnPdnpl=log(Pdnpl);
TFR_norm_npl=2*nnpl_vec;

%Quadratic disutility
%1. only norms - with policy change
phi=(n-nstar)/(nprev-nstar);
psi=0.1;

u0=[3, 0.5];
u = fsolve(@(u) myfun_norm290416(u,tau0, tauh, theta, alpha, psi, nstar, nprev, phi, z, Hbar, H0),u0); 
nn0 = u(1);
hdn0 = u(2);

Ydn0=A*(((Hbar+H0)*N0)^(1-rho))*((L)^(rho));
Pdn0=N0+N0*nn0;
ydn0=Ydn0/Pdn0;
Xdn0=L/N0;

hdn = zeros(1,n_p);
Hdn = zeros(1,n_p);
nn_vec = zeros(1,n_p);
Ndn = zeros(1,n_p);
Pdn = zeros(1,n_p);
Ydn = zeros(1,n_p);
ydn = zeros(1,n_p);
ygrown=zeros(1,n_p-1);
pgrown=zeros(1,n_p-1);
Xdn = zeros(1,n_p);

hdn(1,1)=hdn0;
Hdn(1,1)=H0;
nn_vec(1,1)=nn0;
Ndn(1,1)=N0;
Ydn(1,1)=Ydn0;
ydn(1,1)=ydn0;
Pdn(1,1)=Pdn0;
Xdn(1,1)=Xdn0;


for i=2:n_p
   phi=phi_vec_policy(1,i);
   Hdn(1,i)=z*(Hbar+Hdn(1,i-1))*(hdn(1,i-1));
   H_use=Hdn(1,i);
   Ndn(1,i)=Ndn(1,i-1)*nn_vec(1,i-1);
   nprev_use=nn_vec(1,i-1);
   
   u0=[nn_vec(1,i-1), hdn(1,i-1)];
   u = fsolve(@(u) myfun1_norm290416(u,tau0, tauh, theta, alpha, psi, nstar, nprev_use, phi, z, Hbar, H_use),u0);
   nn_vec(1,i) = u(1);
   hdn(1,i) = u(2);
  
   Ydn(1,i)=A*(((Hbar+Hdn(1,i))*Ndn(1,i))^(1-rho))*((L)^(rho));
   Pdn(1,i)=nn_vec(1,i)*Ndn(1,i)+Ndn(1,i);
   ydn(1,i)=Ydn(1,i)/Pdn(1,i);
   Xdn(1,i)=L/Ndn(1,i);
   ygrown(1,i-1)=(ydn(1,i)-ydn(1,i-1))/ydn(1,i-1);
   pgrown(1,i-1)=(Pdn(1,i)-Pdn(1,i-1))/Pdn(1,i-1);
end    

lnydn=log(ydn);
lnPdn=log(Pdn);
TFR_norm=2*nn_vec;

%3. Norms only with no policy
phi=(n-nstar)/(nprev-nstar);
psi=0.1;

u0=[3, 0.5];
u = fsolve(@(u) myfun_norm290416(u,tau0, tauh, theta, alpha, psi, nstar, nprev, phi, z, Hbar, H0),u0); 
nnp0 = u(1);
hdnp0 = u(2);

Ydnp0=A*(((Hbar+H0)*N0)^(1-rho))*((L)^(rho));
Pdnp0=N0+N0*nnp0;
ydnp0=Ydnp0/Pdnp0;
Xdnp0=L/N0;

hdnp = zeros(1,n_p);
Hdnp = zeros(1,n_p);
nnp_vec = zeros(1,n_p);
Ndnp = zeros(1,n_p);
Pdnp = zeros(1,n_p);
Ydnp = zeros(1,n_p);
ydnp = zeros(1,n_p);
Xdnp = zeros(1,n_p);
ygrownp=zeros(1,n_p-1);
pgrownp=zeros(1,n_p-1);

hdnp(1,1)=hdnp0;
Hdnp(1,1)=H0;
nnp_vec(1,1)=nnp0;
Ndnp(1,1)=N0;
Ydnp(1,1)=Ydnp0;
ydnp(1,1)=ydnp0;
Pdnp(1,1)=Pdnp0;
Xdnp(1,1)=Xdnp0;


for i=2:n_p
   Hdnp(1,i)=z*(Hbar+Hdnp(1,i-1))*(hdnp(1,i-1));
   H_use=Hdnp(1,i);
   Ndnp(1,i)=Ndnp(1,i-1)*nnp_vec(1,i-1);
   nprev_use=nnp_vec(1,i-1);
   
   u0=[nnp_vec(1,i-1), hdnp(1,i-1)];
   u = fsolve(@(u) myfun1_norm290416(u,tau0, tauh, theta, alpha, psi, nstar, nprev_use, phi, z, Hbar, H_use),u0);
   nnp_vec(1,i) = u(1);
   hdnp(1,i) = u(2);
  
   Ydnp(1,i)=A*(((Hbar+Hdnp(1,i))*Ndnp(1,i))^(1-rho))*((L)^(rho));
   Pdnp(1,i)=nnp_vec(1,i)*Ndnp(1,i)+Ndnp(1,i);
   ydnp(1,i)=Ydnp(1,i)/Pdnp(1,i);
   Xdnp(1,i)=L/Ndnp(1,i);
   
   ygrownp(1,i-1)=(ydnp(1,i)-ydnp(1,i-1))/ydnp(1,i-1);
   pgrownp(1,i-1)=(Pdnp(1,i)-Pdnp(1,i-1))/Pdnp(1,i-1);
end    

lnydnp=log(ydnp);
lnPdnp=log(Pdnp);
TFR_norm_np=2*nnp_vec;

TFR_data=[5.97;	3.94; 2.51];
h_data=[5; 7.846254; 10.67555];

subplot(1,2,1);
plot(TFR_norm,'-g','DisplayName','TFR_norm','LineWidth',2);
hold all;
plot(TFR_norm_np,'--m','DisplayName','TFR_norm_np','LineWidth',2);
hold all;
plot(TFR_norml,':r','DisplayName','TFR_norml','LineWidth',2);
hold all;
plot(TFR_norm_npl,'-.b','DisplayName','TFR_norm_npl','LineWidth',2);
hold all;
plot(TFR_data,'+','DisplayName','TFR_data', 'MarkerEdgeColor', 'k', 'MarkerSize', 8);
hold off;

title('Fertility', 'fontsize',14);
xlabel('t', 'fontsize',14);

subplot(1,2,2);
plot(hdn,'-g','DisplayName','hdn','LineWidth',2);
hold all;
plot(hdnp,'--m','DisplayName','hdnp','LineWidth',2);
hold all;
plot(hdnl,':r','DisplayName','hdnl','LineWidth',2);
hold all;
plot(hdnpl,'-.b','DisplayName','hdnpl','LineWidth',2);
hold all;
plot(h_data,'+','DisplayName','hb', 'MarkerEdgeColor', 'k', 'MarkerSize', 8);
hold off;
title('Human capital investment', 'fontsize',14);
xlabel('t', 'fontsize',14);

ax1 = subplot(1,2,1);
ylabel(ax1,'TFR', 'fontsize',14);
ax2 = subplot(1,2,2);
ylabel(ax2,'Years of schooling', 'fontsize',14);


leg=legend('quadratic - with policy', 'quadratic - no policy', 'log - with policy', 'log - without policy','Orientation','horizontal');
set(leg, 'fontsize',12);
