%values from data (weighted by working age population)
n=2.99;
h=5;
c=1258.816; %hh consumption per worker
y0=1508.905; %output per worker
y1=2959.06;
N0=2.02;
N1=3.52;
mincer=0.11;
taug=0.045;

rho=0.33;
tau1=0.007;
hbar=1;
gA=1.56;

tauh=tau1+(taug/(n*h));

u0=[0.02, 2.7, 0.11];
u = fsolve(@(u) calibration(u, tauh, c, n, h, y0, y1, N0, N1, rho, gA),u0); 

tau0=u(1);
gH=u(2);
alpha=u(3);

z_lower=(gH-1)/h;
z_upper=gH/h;

z_vec=linspace(z_lower+0.001, z_upper-0.001, 9);
theta_vec=zeros(1, 9);
H0_vec=zeros(1, 9);

for i=1:9
    z=z_vec(1,i);
    x0=[0.02, 2.7];
    x = fsolve(@(x) calibration2(x, tauh, c, n, h, y0, gH, z, hbar),x0); 

    theta_vec(1,i)=x(1);
    H0_vec(1,i)=x(2);
end;

z_ideal=mincer*gH/(1-rho);
if (z_ideal<=z_upper) && (z_ideal>=z_lower)
    z=z_ideal;
    theta=gH*(tauh*n*y0/(z*c));
    H0=hbar*((1/(gH-(z*h)))-1);
elseif (z_ideal>=z_upper)
    z=z_upper;
    theta=theta_vec(1,9);
    H0=H0_vec(1,9);
else 
    z=z_lower;
    theta=theta_vec(1,1);
    H0=H0_vec(1,1);
end


%calibration of phi
psi=0.1;
nstar=1;
nprev=3.5;
lamda=1;
phi=(2*psi*n*(n-nstar)-alpha*(1-(alpha^2))*(lamda/(n^2)))/(2*psi*n*(nprev-nstar));
Hbar=hbar;

L=1; %land stock
A=1; %production technology
N0=2.21; %initial working age population

n_p=10;

phi_vec_policy=zeros(1,n_p);
phi_vec_policy(1,1)=phi;
phi_vec_policy(1,2)=0.6;
phi_vec_policy(1,3)=0.37;
for i=4:n_p
    phi_vec_policy(1,i)=0.37;
end


lamda_vec_policy=zeros(1,n_p);
lamda_vec_policy(1,1)=1;
lamda_vec_policy(1,2)=0.55;
lamda_vec_policy(1,3)=0.31;
for i=4:n_p
  lamda_vec_policy(1,i)=0.31;
end

%1. Full version with policy intervention
u0=[3, 0.5];
u = fsolve(@(u) myfun_290416(u,tau0, tauh, theta, alpha, psi, phi, nstar, nprev, z, Hbar, H0, lamda),u0); 
ndp0 = u(1);
nap0 = ndp0+lamda;
hdp0 = u(2);

Ydp0=A*(((Hbar+H0)*N0)^(1-rho))*((L)^(rho));
Pdp0=N0+nap0*N0;
ydp0=Ydp0/Pdp0;
Xd0=L/N0;

hdp = zeros(1,n_p);
Hdp = zeros(1,n_p);
ndp_vec = zeros(1,n_p);
nap_vec = zeros(1,n_p);
Ndp = zeros(1,n_p);
Pdp = zeros(1,n_p);
Ydp = zeros(1,n_p);
ydp = zeros(1,n_p);
Xdp = zeros(1,n_p);

hdp(1,1)=hdp0;
Hdp(1,1)=H0;
ndp_vec(1,1)=ndp0;
nap_vec(1,1)=nap0;
Ndp(1,1)=N0;
Ydp(1,1)=Ydp0;
ydp(1,1)=ydp0;
Pdp(1,1)=Pdp0;
Xdp(1,1)=Xd0;


for i=2:n_p
   phi=phi_vec_policy(1,i);
   lamda=lamda_vec_policy(1,i);
   Hdp(1,i)=z*(Hbar+Hdp(1,i-1))*(hdp(1,i-1));
   H_use=Hdp(1,i);
   Ndp(1,i)=Ndp(1,i-1)*nap_vec(1,i-1);
   nprev_use=nap_vec(1,i-1);
   
   u0=[ndp_vec(1,i-1), hdp(1,i-1)];
   u = fsolve(@(u) myfun1_290416(u,tau0, tauh, theta, alpha, psi, phi, nstar, nprev_use, z, Hbar, H0, lamda),u0);
   ndp_vec(1,i) = u(1);
   nap_vec(1,i) = u(1)+lamda;
   hdp(1,i) = u(2);
  
   Ydp(1,i)=A*(((Hbar+Hdp(1,i))*Ndp(1,i))^(1-rho))*(L^(rho));
   Pdp(1,i)=nap_vec(1,i)*Ndp(1,i)+Ndp(1,i);
   ydp(1,i)=Ydp(1,i)/Pdp(1,i);
   Xdp(1,i)=L/Ndp(1,i);
end    

lnydp=log(ydp);
lnPdp=log(Pdp);
TFR_p=2*nap_vec;
TFR_wanted=2*ndp_vec;


%2. Full version with policy intervention but no change in unwanted fertility
lamda=1;
phi=(n-nstar)/(nprev-nstar);
u0=[3, 0.5];
u = fsolve(@(u) myfun_290416(u,tau0, tauh, theta, alpha, psi, phi, nstar, nprev, z, Hbar, H0, lamda),u0); 
ndp10 = u(1);
nap10 = ndp10+lamda;
hdp10 = u(2);

Ydp10=A*(((Hbar+H0)*N0)^(1-rho))*((L)^(rho));
Pdp10=N0+nap10*N0;
ydp10=Ydp10/Pdp10;
Xd10=L/N0;

hdp1 = zeros(1,n_p);
Hdp1 = zeros(1,n_p);
ndp1_vec = zeros(1,n_p);
nap1_vec = zeros(1,n_p);
Ndp1 = zeros(1,n_p);
Pdp1 = zeros(1,n_p);
Ydp1 = zeros(1,n_p);
ydp1 = zeros(1,n_p);
Xdp1 = zeros(1,n_p);

hdp1(1,1)=hdp10;
Hdp1(1,1)=H0;
ndp1_vec(1,1)=ndp0;
nap1_vec(1,1)=nap0;
Ndp1(1,1)=N0;
Ydp1(1,1)=Ydp0;
ydp1(1,1)=ydp0;
Pdp1(1,1)=Pdp0;
Xdp1(1,1)=Xd0;


for i=2:n_p
   phi=phi_vec_policy(1,i);
   Hdp1(1,i)=z*(Hbar+Hdp1(1,i-1))*(hdp1(1,i-1));
   H_use=Hdp1(1,i);
   Ndp1(1,i)=Ndp1(1,i-1)*nap1_vec(1,i-1);
   nprev_use=nap1_vec(1,i-1);
   
   u0=[ndp1_vec(1,i-1), hdp1(1,i-1)];
   u = fsolve(@(u) myfun1_290416(u,tau0, tauh, theta, alpha, psi, phi, nstar, nprev_use, z, Hbar, H0, lamda),u0);
   ndp1_vec(1,i) = u(1);
   nap1_vec(1,i) = u(1)+lamda;
   hdp1(1,i) = u(2);
  
   Ydp1(1,i)=A*(((Hbar+Hdp1(1,i))*Ndp1(1,i))^(1-rho))*(L^(rho));
   Pdp1(1,i)=nap1_vec(1,i)*Ndp1(1,i)+Ndp1(1,i);
   ydp1(1,i)=Ydp1(1,i)/Pdp1(1,i);
   Xdp1(1,i)=L/Ndp1(1,i);
end    

lnydp1=log(ydp1);
lnPdp1=log(Pdp1);
TFR_p1=2*nap1_vec;
TFR_wanted1=2*ndp1_vec;



TFR_data=[5.97;	3.94; 2.51];
h_data=[5; 7.846254; 10.67555];
popgrowth_data=[0.56;0.32];
ygrowth_data=[1;1.5];

subplot(1,2,1);
plot(TFR_p,'--r','DisplayName','TFR_p','LineWidth',2);
hold all;
plot(TFR_p1,'-g','DisplayName','TFR_norm','LineWidth',2);
hold all;
plot(TFR_data,'+','DisplayName','TFR_data', 'MarkerEdgeColor', 'k', 'MarkerSize', 8);
hold off;
title('Fertility', 'fontsize',14);
xlabel('t', 'fontsize',14);

subplot(1,2,2);
plot(hdp,'--r','DisplayName','hdp','LineWidth',2);
hold all;
plot(hdp1,'-g','DisplayName','hdn','LineWidth',2);
hold all;
plot(h_data,'+','DisplayName','hb', 'MarkerEdgeColor', 'k', 'MarkerSize', 8);
hold off;
title('Human capital investment', 'fontsize',14);
xlabel('t', 'fontsize',14);


ax1 = subplot(1,2,1);
ylabel(ax1,'TFR', 'fontsize',14);
ax2 = subplot(1,2,2);
ylabel(ax2,'Years of education', 'fontsize',14);


leg=legend('Changing norms+unwanted fertility','Changing norms only','Orientation','horizontal');
set(leg, 'fontsize',12);